@@ -102,33 +102,7 @@ class RabbitMQMessager(object):
 
             :returns:  bool -- Connection status. True for correct connection.
         """
-        if self.channel is None:
-            return False
-        return True
-
-    def send(self, topic, message, out=sys.stdout):
-        """Method that send a message with a topic.
-
-            :param topic: Channel where to send message (RabbitMQ filter).
-            :type topic: str.
-
-            :param message: Message to send to RabbitMQ.
-            :type message: str.
-
-            :param out: Stdout redirection in case of test (default: stdout).
-            :type out: StringIO.
-        """
-        # We log message we want to send to keep a trace
-        self.logger.error(message)
-        # If channel is available
-        if self.channel is not None:
-            # We send a message on this channel
-            self.channel.queue_declare(queue=topic)
-            self.channel.basic_publish(
-                exchange='', routing_key=topic, body=message)
-        else:
-            # Else we print it in stdout
-            out.write("%s %s" % (unicode(message), "\n"))
+        return True if self.channel is not None else False
 
     def send_message(self, topic, site_name, var_name, data, out=sys.stdout):
         """Format parameter into json string for phase platform.
@@ -160,7 +134,31 @@ class RabbitMQMessager(object):
         # And we send it using our send method defined previously
         self.send(topic, json.dumps(json_message), out)
 
-    def consume(self, topics, callback):
+    def send_worker(self, topic, message, out=sys.stdout):
+        """Method that send a message with a topic.
+
+            :param topic: Channel where to send message (RabbitMQ filter).
+            :type topic: str.
+
+            :param message: Message to send to RabbitMQ.
+            :type message: str.
+
+            :param out: Stdout redirection in case of test (default: stdout).
+            :type out: StringIO.
+        """
+        # We log message we want to send to keep a trace
+        self.logger.error(message)
+        # If channel is available
+        if self.channel is not None:
+            # We send a message on this channel
+            self.channel.queue_declare(queue=topic)
+            self.channel.basic_publish(
+                exchange='', routing_key=topic, body=message)
+        else:
+            # Else we print it in stdout
+            out.write("%s %s" % (unicode(message), "\n"))
+
+    def consume_worker(self, topics, callback):
         """Method that wait for a message on RabbitMQ topics channels.
 
             :param topic: Channel where to send message (RabbitMQ filter).
@@ -178,3 +176,54 @@ class RabbitMQMessager(object):
         except pika.exceptions.ConnectionClosed:
             # If something goes wrong we pass silently
             pass
+
+    def send(self, topic, message, out=sys.stdout):
+        """Method that send a message with a topic.
+
+            :param topic: Channel where to send message (RabbitMQ filter).
+            :type topic: str.
+
+            :param message: Message to send to RabbitMQ.
+            :type message: str.
+
+            :param out: Stdout redirection in case of test (default: stdout).
+            :type out: StringIO.
+        """
+        # We log message we want to send to keep a trace
+        self.logger.error(message)
+        # If channel is available
+        if self.channel is not None:
+            # We send a message on this channel
+            self.channel.exchange_declare(exchange=topic, type='fanout')
+            self.channel.basic_publish(
+                exchange=topic,
+                routing_key=topic,
+                body=message)
+        else:
+            # Else we print it in stdout
+            out.write("%s %s" % (unicode(message), "\n"))
+
+    def consume(self, topics, callback):
+        """Method that wait for a message on RabbitMQ topics channels.
+
+            :param topic: Channel where to send message (RabbitMQ filter).
+            :type topic: str.
+
+            :param callback: Function that compute result of message (async).
+            :type callback: Function.
+        """
+        # We try to connect to our channel and wait for a message
+        try:
+            for topic in topics:
+                self.channel.exchange_declare(exchange=topic, type='fanout')
+                result = self.channel.queue_declare(exclusive=True)
+                queue_name = result.method.queue
+                self.channel.queue_bind(exchange=topic, queue=queue_name)
+                self.channel.basic_consume(
+                    callback,
+                    queue=queue_name,
+                    no_ack=True)
+            self.channel.start_consuming()
+        except pika.exceptions.ConnectionClosed:
+            # If something goes wrong we pass silently
+            pass
